#!/usr/bin/env bash

cd "$(dirname "$0")"

# turn on verbose debugging output for parabuild logs.
exec 4>&1; export BASH_XTRACEFD=4; set -x
# make errors fatal
set -e
# complain about unset env variables
set -u

if [ -z "$AUTOBUILD" ] ; then 
    exit 1
fi

if [ "$OSTYPE" = "cygwin" ] ; then
    autobuild="$(cygpath -u $AUTOBUILD)"
else
    autobuild="$AUTOBUILD"
fi

top="$(pwd)"
stage="$(pwd)/stage"

mkdir -p $stage

# Load autobuild provided shell functions and variables
source_environment_tempfile="$stage/source_environment.sh"
"$autobuild" source_environment > "$source_environment_tempfile"
. "$source_environment_tempfile"

DISCORDRPC_VERSION="3.4.0"
DISCORDRPC_SOURCE_DIR="discord-rpc"

build=${AUTOBUILD_BUILD_ID:=0}

echo "${DISCORDRPC_VERSION}.${build}" > "${stage}/VERSION.txt"

# Create the staging folders
mkdir -p "$stage/lib"/{debug,release}
mkdir -p "$stage/include/discord_rpc"
mkdir -p "$stage/LICENSES"

pushd "$DISCORDRPC_SOURCE_DIR"
    case "$AUTOBUILD_PLATFORM" in

        # ------------------------ windows, windows64 ------------------------
        windows*)
            load_vsvars

            cmake . -G "$AUTOBUILD_WIN_CMAKE_GEN" -DCMAKE_INSTALL_PREFIX=$stage
            
            cmake --build . --config Debug --clean-first
            cmake --build . --config Release --clean-first

            mkdir -p "$stage/lib/debug"
            mkdir -p "$stage/lib/release"
            cp src/Release/discord-rpc.lib "$stage/lib/release"
            cp src/Debug/discord-rpc{.lib,.pdb} "$stage/lib/debug"
            mkdir -p "$stage/include/discord_rpc"
            cp include/*.h "$stage/include/discord_rpc"
        ;;

        "darwin")
	  
        ;;
        "linux")

        ;;
        "linux64")

        ;;
    esac
    mkdir -p "$stage/LICENSES"
    cp LICENSE "$stage/LICENSES/discord-rpc.txt"
popd
